@@ -110,13 +110,19 @@ def extrapolate(
     if velocity.ndim != 3:
         raise ValueError("velocity must be a three-dimensional array")
 
-    if precip is not None and not allow_nonfinite_values:
-        if np.any(~np.isfinite(precip)):
+    if not allow_nonfinite_values:
+        if precip is not None and np.any(~np.isfinite(precip)):
             raise ValueError("precip contains non-finite values")
 
         if np.any(~np.isfinite(velocity)):
             raise ValueError("velocity contains non-finite values")
 
+    if precip is not None and np.all(~np.isfinite(precip)):
+        raise ValueError("precip contains only non-finite values")
+
+    if np.all(~np.isfinite(velocity)):
+        raise ValueError("velocity contains only non-finite values")
+
     if isinstance(timesteps, list) and not sorted(timesteps) == timesteps:
         raise ValueError("timesteps is not in ascending order")
 
