@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 pysteps.io.exporters
 ====================
@@ -136,23 +137,23 @@ def initialize_forecast_exporter_geotiff(
 
     Parameters
     ----------
-    outpath : str
+    outpath: str
         Output path.
 
-    outfnprefix : str
+    outfnprefix: str
         Prefix for output file names.
 
-    startdate : datetime.datetime
+    startdate: datetime.datetime
         Start date of the forecast.
 
-    timestep : int
+    timestep: int
         Time step of the forecast (minutes).
 
-    n_timesteps : int
+    n_timesteps: int
         Number of time steps in the forecast. This argument is ignored if
         incremental is set to 'timestep'.
 
-    shape : tuple of int
+    shape: tuple of int
         Two-element tuple defining the shape (height,width) of the forecast
         grids.
 
@@ -161,10 +162,10 @@ def initialize_forecast_exporter_geotiff(
         attributes described in the documentation of
         :py:mod:`pysteps.io.importers`.
 
-    n_ens_members : int
+    n_ens_members: int
         Number of ensemble members in the forecast.
 
-    incremental : {None,'timestep'}, optional
+    incremental: {None,'timestep'}, optional
         Allow incremental writing of datasets into the GeoTIFF files. Set to
         'timestep' to enable writing forecasts or forecast ensembles separately
         for each time step. If set to None, incremental writing is disabled and
@@ -173,7 +174,7 @@ def initialize_forecast_exporter_geotiff(
 
     Returns
     -------
-    exporter : dict
+    exporter: dict
         The return value is a dictionary containing an exporter object.
         This can be used with
         :py:func:`pysteps.io.exporters.export_forecast_dataset`
@@ -181,6 +182,11 @@ def initialize_forecast_exporter_geotiff(
 
     """
 
+    if len(shape) != 2:
+        raise ValueError("shape has %d elements, 2 expected" % len(shape))
+
+    del kwargs  # kwargs not used
+
     if not GDAL_IMPORTED:
         raise MissingOptionalDependency(
             "gdal package is required for GeoTIFF " "exporters but it is not installed"
@@ -192,18 +198,18 @@ def initialize_forecast_exporter_geotiff(
             + " the 'member' option is not supported"
         )
 
-    exporter = {}
-    exporter["method"] = "geotiff"
-    exporter["outfnprefix"] = outfnprefix
-    exporter["startdate"] = startdate
-    exporter["timestep"] = timestep
-    exporter["num_timesteps"] = n_timesteps
-    exporter["shape"] = shape
-    exporter["metadata"] = metadata
-    exporter["num_ens_members"] = n_ens_members
-    exporter["incremental"] = incremental
-    exporter["dst"] = []
-
+    exporter = dict(
+        method="geotiff",
+        outfnprefix=outfnprefix,
+        startdate=startdate,
+        timestep=timestep,
+        num_timesteps=n_timesteps,
+        shape=shape,
+        metadata=metadata,
+        num_ens_members=n_ens_members,
+        incremental=incremental,
+        dst=[],
+    )
     driver = gdal.GetDriverByName("GTiff")
     exporter["driver"] = driver
 
@@ -238,8 +244,8 @@ def initialize_forecast_exporter_kineros(
     incremental=None,
     **kwargs,
 ):
-    """Initialize a KINEROS2 Rainfall .pre file as specified
-    in https://www.tucson.ars.ag.gov/kineros/.
+    """Initialize a KINEROS2 format exporter for the rainfall ".pre" files
+    specified in https://www.tucson.ars.ag.gov/kineros/.
 
     Grid points are treated as individual rain gauges and a separate file is
     produced for each ensemble member. The output files are named as
@@ -248,23 +254,23 @@ def initialize_forecast_exporter_kineros(
 
     Parameters
     ----------
-    outpath : str
+    outpath: str
         Output path.
 
-    outfnprefix : str
+    outfnprefix: str
         Prefix for output file names.
 
-    startdate : datetime.datetime
+    startdate: datetime.datetime
         Start date of the forecast.
 
-    timestep : int
+    timestep: int
         Time step of the forecast (minutes).
 
-    n_timesteps : int
+    n_timesteps: int
         Number of time steps in the forecast this argument is ignored if
         incremental is set to 'timestep'.
 
-    shape : tuple of int
+    shape: tuple of int
         Two-element tuple defining the shape (height,width) of the forecast
         grids.
 
@@ -273,16 +279,16 @@ def initialize_forecast_exporter_kineros(
         attributes described in the documentation of
         :py:mod:`pysteps.io.importers`.
 
-    n_ens_members : int
+    n_ens_members: int
         Number of ensemble members in the forecast. This argument is ignored if
         incremental is set to 'member'.
 
-    incremental : {None}, optional
+    incremental: {None}, optional
         Currently not implemented for this method.
 
     Returns
     -------
-    exporter : dict
+    exporter: dict
         The return value is a dictionary containing an exporter object. This c
         an be used with :py:func:`pysteps.io.exporters.export_forecast_dataset`
         to write datasets into the given file format.
@@ -371,36 +377,28 @@ def initialize_forecast_exporter_netcdf(
 
     Parameters
     ----------
-    outpath : str
+    outpath: str
         Output path.
-
-    outfnprefix : str
+    outfnprefix: str
         Prefix for output file names.
-
-    startdate : datetime.datetime
+    startdate: datetime.datetime
         Start date of the forecast.
-
-    timestep : int
+    timestep: int
         Time step of the forecast (minutes).
-
-    n_timesteps : int
+    n_timesteps: int
         Number of time steps in the forecast this argument is ignored if
         incremental is set to 'timestep'.
-
-    shape : tuple of int
+    shape: tuple of int
         Two-element tuple defining the shape (height,width) of the forecast
         grids.
-
     metadata: dict
-        Metadata dictionary containing the projection,x1,x2,y1,y2 and unit
-        attributes described in the documentation of
-        :py:mod:`pysteps.io.importers`.
-
-    n_ens_members : int
+        Metadata dictionary containing the projection, x1, x2, y1, y2,
+        unit attributes (projection and variable units) described in the
+        documentation of :py:mod:`pysteps.io.importers`.
+    n_ens_members: int
         Number of ensemble members in the forecast. This argument is ignored if
         incremental is set to 'member'.
-
-    incremental : {None,'timestep','member'}, optional
+    incremental: {None,'timestep','member'}, optional
         Allow incremental writing of datasets into the netCDF files.\n
         The available options are: 'timestep' = write a forecast or a forecast
         ensemble for  a given time step; 'member' = write a forecast sequence
@@ -409,12 +407,12 @@ def initialize_forecast_exporter_netcdf(
 
     Returns
     -------
-    exporter : dict
+    exporter: dict
         The return value is a dictionary containing an exporter object. This c
         an be used with :py:func:`pysteps.io.exporters.export_forecast_dataset`
         to write datasets into the given file format.
-
     """
+
     if not NETCDF4_IMPORTED:
         raise MissingOptionalDependency(
             "netCDF4 package is required for netcdf "
@@ -428,8 +426,8 @@ def initialize_forecast_exporter_netcdf(
 
     if incremental not in [None, "timestep", "member"]:
         raise ValueError(
-            "unknown option %s: incremental must be "
-            + "'timestep' or 'member'" % incremental
+            f"unknown option {incremental}: incremental must be "
+            + "'timestep' or 'member'"
         )
 
     if incremental == "timestep":
@@ -438,8 +436,8 @@ def initialize_forecast_exporter_netcdf(
         n_ens_members = None
     elif incremental is not None:
         raise ValueError(
-            "unknown argument value incremental='%s': "
-            + "must be 'timestep' or 'member'" % str(incremental)
+            f"unknown argument value incremental='{str(incremental)}': "
+            + "must be 'timestep' or 'member'"
         )
 
     n_ens_gt_one = False
@@ -499,29 +497,27 @@ def initialize_forecast_exporter_netcdf(
     var_xc.axis = "X"
     var_xc.standard_name = "projection_x_coordinate"
     var_xc.long_name = "x-coordinate in Cartesian system"
-    # TODO(exporters): Don't hard-code the unit.
-    var_xc.units = "m"
+    var_xc.units = metadata["cartesian_unit"]
 
     var_yc = ncf.createVariable("y", np.float32, dimensions=("y",))
     var_yc[:] = yr
     var_yc.axis = "Y"
     var_yc.standard_name = "projection_y_coordinate"
     var_yc.long_name = "y-coordinate in Cartesian system"
-    # TODO(exporters): Don't hard-code the unit.
-    var_yc.units = "m"
+    var_yc.units = metadata["cartesian_unit"]
 
     x_2d, y_2d = np.meshgrid(xr, yr)
     pr = pyproj.Proj(metadata["projection"])
     lon, lat = pr(x_2d.flatten(), y_2d.flatten(), inverse=True)
 
-    var_lon = ncf.createVariable("lon", np.float, dimensions=("y", "x"))
+    var_lon = ncf.createVariable("lon", float, dimensions=("y", "x"))
     var_lon[:] = lon.reshape(shape)
     var_lon.standard_name = "longitude"
     var_lon.long_name = "longitude coordinate"
     # TODO(exporters): Don't hard-code the unit.
     var_lon.units = "degrees_east"
 
-    var_lat = ncf.createVariable("lat", np.float, dimensions=("y", "x"))
+    var_lat = ncf.createVariable("lat", float, dimensions=("y", "x"))
     var_lat[:] = lat.reshape(shape)
     var_lat.standard_name = "latitude"
     var_lat.long_name = "latitude coordinate"
@@ -537,21 +533,20 @@ def initialize_forecast_exporter_netcdf(
     ) = _convert_proj4_to_grid_mapping(metadata["projection"])
     # skip writing the grid mapping if a matching name was not found
     if grid_mapping_var_name is not None:
-        var_gm = ncf.createVariable(grid_mapping_var_name, np.int, dimensions=())
+        var_gm = ncf.createVariable(grid_mapping_var_name, int, dimensions=())
         var_gm.grid_mapping_name = grid_mapping_name
         for i in grid_mapping_params.items():
             var_gm.setncattr(i[0], i[1])
 
     if incremental == "member" or n_ens_gt_one:
-        var_ens_num = ncf.createVariable(
-            "ens_number", np.int, dimensions=("ens_number",)
-        )
+        var_ens_num = ncf.createVariable("ens_number", int, dimensions=("ens_number",))
         if incremental != "member":
             var_ens_num[:] = list(range(1, n_ens_members + 1))
         var_ens_num.long_name = "ensemble member"
+        var_ens_num.standard_name = "realization"
         var_ens_num.units = ""
 
-    var_time = ncf.createVariable("time", np.int, dimensions=("time",))
+    var_time = ncf.createVariable("time", int, dimensions=("time",))
     if incremental != "timestep":
         var_time[:] = [i * timestep * 60 for i in range(1, n_timesteps + 1)]
     var_time.long_name = "forecast time"
@@ -609,10 +604,10 @@ def export_forecast_dataset(field, exporter):
 
     Parameters
     ----------
-    exporter : dict
+    exporter: dict
         An exporter object created with any initialization method implemented
         in :py:mod:`pysteps.io.exporters`.
-    field : array_like
+    field: array_like
         The array to write. The required shape depends on the choice of the
         'incremental' parameter the exporter was initialized with:
 
@@ -628,8 +623,8 @@ def export_forecast_dataset(field, exporter):
 
         If the exporter was initialized with num_ens_members=1,
         the num_ens_members dimension is dropped.
-
     """
+
     if exporter["method"] == "netcdf" and not NETCDF4_IMPORTED:
         raise MissingOptionalDependency(
             "netCDF4 package is required for netcdf "
@@ -692,11 +687,11 @@ def close_forecast_files(exporter):
 
     Parameters
     ----------
-    exporter : dict
+    exporter: dict
         An exporter object created with any initialization method implemented
         in :py:mod:`pysteps.io.exporters`.
-
     """
+
     if exporter["method"] == "geotiff":
         pass  # NOTE: There is no explicit "close" method in GDAL.
         # The files are closed when all objects referencing to the GDAL
@@ -772,6 +767,9 @@ def _export_kineros(field, exporter):
 
     timemin = [(t + 1) * timestep for t in range(num_timesteps)]
 
+    if field.ndim == 3:
+        field = field.reshape((1,) + field.shape)
+
     for n in range(num_ens_members):
         file_name = exporter["ncfile"][n]
 
